@@ -22,6 +22,7 @@
 #' @param font.main font to be used for plot main titles
 #' @param customPar logical defaults to FALSE. If TRUE, par() should be set by user before calling this function 
 #' @param las numeric in {0,1,2,3}; the style of axis labels
+#' @param randomCensored logical. Show censored residuals as randomized.
 #' @param \dots arbitrary graphical parameters that will be passed to genericEGRETDotPlot function (see ?par for options)
 #' @keywords graphics water-quality statistics
 #' @seealso \code{\link[graphics]{boxplot}}
@@ -35,7 +36,7 @@
 #' boxResidMonth(eList)
 boxResidMonth<-function(eList, stdResid = FALSE, las=1,
                         printTitle = TRUE, cex=0.8, cex.axis=1.1, cex.main=1.1,
-                        font.main=2, tinyPlot=FALSE, customPar=FALSE,...) {
+                        font.main=2, tinyPlot=FALSE, customPar=FALSE,randomCensored=FALSE,...) {
   
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
@@ -64,15 +65,15 @@ boxResidMonth<-function(eList, stdResid = FALSE, las=1,
   
   plotTitle<-if(printTitle) paste(localINFO$shortName,"\n",localINFO$paramShortName,"\nBoxplots of residuals by month") else ""
   
-  # if(!rResid){
+  if(!randomCensored){
     resid<-log(localSample$ConcAve) - localSample$yHat
-  # } else {
-  #   if(!("rResid" %in% names(localSample))){
-  #     eList <- makeAugmentedSample(eList)
-  #     localSample <- eList$Sample
-  #   }
-  #   resid <- localSample$rResid
-  # }
+  } else {
+    if(!("rResid" %in% names(localSample))){
+      eList <- makeAugmentedSample(eList)
+      localSample <- eList$Sample
+    }
+    resid <- localSample$rResid
+  }
   
   if(stdResid) {
     resid<- resid/localSample$SE
@@ -96,5 +97,5 @@ boxResidMonth<-function(eList, stdResid = FALSE, las=1,
           ...)
   abline(h=0)  
   if (!tinyPlot) mtext(title2,side=3,line=-1.5)
-  # invisible(eList)
+  invisible(eList)
 }
\ No newline at end of file
