@@ -24,6 +24,7 @@
 #' (for example, adjusting margins with par(mar=c(5,5,5,5))). If customPar FALSE, EGRET chooses the best margins depending on tinyPlot.
 #' @param col color of points on plot, see ?par 'Color Specification'
 #' @param lwd number line width
+#' @param randomCensored logical. Show censored values as randomized.
 #' @param \dots arbitrary graphical parameters that will be passed to genericEGRETDotPlot function (see ?par for options)
 #' @keywords graphics water-quality statistics
 #' @export
@@ -36,12 +37,9 @@
 #' # Graphs consisting of Jun-Aug
 #' eList <- setPA(eList, paStart=6,paLong=3)
 #' plotConcQ(eList)
-plotConcQ<-function(eList, qUnit = 2, tinyPlot = FALSE, logScale=FALSE,
+plotConcQ<-function(eList, qUnit = 2, tinyPlot = FALSE, logScale=FALSE,randomCensored=FALSE,
                     concMax = NA, concMin =NA, printTitle = TRUE, cex=0.8, cex.axis=1.1,cex.main=1.1,
                     rmSciX=FALSE,rmSciY=FALSE, customPar=FALSE,col="black",lwd=1,...){
-  # this function shows the sample data,
-  # discharge on x-axis on a log scale, concentration on y-axis
-  
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
   
@@ -52,7 +50,7 @@ plotConcQ<-function(eList, qUnit = 2, tinyPlot = FALSE, logScale=FALSE,
     paLong <- 12
     paStart <- 10
   }
-
+  
   localSample <- if(paLong == 12) localSample else selectDays(localSample, paLong,paStart)
   title2<-if(paLong==12) "" else setSeasonLabelByUser(paStartInput=paStart,paLongInput=paLong)
   
@@ -68,7 +66,7 @@ plotConcQ<-function(eList, qUnit = 2, tinyPlot = FALSE, logScale=FALSE,
   x<-localSample$Q*qFactor
   
   Uncen<-localSample$Uncen
-
+  
   plotTitle<-if(printTitle) paste(localINFO$shortName,"\n",localINFO$paramShortName,"\n","Concentration versus Discharge") else ""
   
   if (tinyPlot){
@@ -87,22 +85,42 @@ plotConcQ<-function(eList, qUnit = 2, tinyPlot = FALSE, logScale=FALSE,
   
   xInfo <- generalAxis(x=x, maxVal=NA, minVal=NA, logScale=TRUE, tinyPlot=tinyPlot)
   
-  yLow<-localSample$ConcLow
-  yHigh<-localSample$ConcHigh
-  
-  yInfo <- generalAxis(x=yHigh, maxVal=concMax, minVal=yMin, tinyPlot=tinyPlot,logScale=logScale,units=localINFO$param.units)
-  
-  genericEGRETDotPlot(x=x, y=yHigh, 
-                      xlim=c(xInfo$bottom, xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
-                      xlab=xLab, ylab=yInfo$label,
-                      xTicks=xInfo$ticks, yTicks=yInfo$ticks,
-                      plotTitle=plotTitle, log=logScaleText,cex.axis=cex.axis,cex=cex,
-                      cex.main=cex.main, tinyPlot=tinyPlot,xaxt="n",
-                      rmSciX=rmSciX,rmSciY=rmSciY,customPar=customPar,col=col,lwd=lwd,...
-  )
-  
-  censoredSegments(yInfo$bottom, yLow, yHigh, x, Uncen,col=col,lwd=lwd)
-
+  if(!randomCensored){
+    yLow<-localSample$ConcLow
+    yHigh<-localSample$ConcHigh
+    
+    yInfo <- generalAxis(x=yHigh, maxVal=concMax, minVal=yMin, tinyPlot=tinyPlot,logScale=logScale,units=localINFO$param.units)
+    
+    genericEGRETDotPlot(x=x, y=yHigh, 
+                        xlim=c(xInfo$bottom, xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        xlab=xLab, ylab=yInfo$label,
+                        xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        plotTitle=plotTitle, log=logScaleText,cex.axis=cex.axis,cex=cex,
+                        cex.main=cex.main, tinyPlot=tinyPlot,xaxt="n",
+                        rmSciX=rmSciX,rmSciY=rmSciY,customPar=customPar,col=col,lwd=lwd,...
+    )
+    
+    censoredSegments(yInfo$bottom, yLow, yHigh, x, Uncen,col=col,lwd=lwd)
+  } else {
+    if(!("rObserved" %in% names(localSample))){
+      eList <- makeAugmentedSample(eList)
+      localSample <- eList$Sample
+    }
+    yHigh <- localSample$rObserved
+    
+    yInfo <- generalAxis(x=yHigh, maxVal=concMax, minVal=yMin, tinyPlot=tinyPlot,logScale=logScale,units=localINFO$param.units)
+    
+    genericEGRETDotPlot(x=x[Uncen == 1], y=yHigh[Uncen == 1], 
+                        xlim=c(xInfo$bottom, xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        xlab=xLab, ylab=yInfo$label,
+                        xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        plotTitle=plotTitle, log=logScaleText,cex.axis=cex.axis,cex=cex,
+                        cex.main=cex.main, tinyPlot=tinyPlot,xaxt="n",
+                        rmSciX=rmSciX,rmSciY=rmSciY,customPar=customPar,col=col,lwd=lwd,...
+    )
+    points(x=x[Uncen == 0], y=yHigh[Uncen == 0], pch=1,cex=cex,col=col)
+    
+  }
   if (!tinyPlot) mtext(title2,side=3,line=-1.5)
 
 }
