@@ -20,6 +20,7 @@
 #' (for example, adjusting margins with par(mar=c(5,5,5,5))). If customPar FALSE, EGRET chooses the best margins depending on tinyPlot.
 #' @param col color of points on plot, see ?par 'Color Specification'
 #' @param lwd number line width
+#' @param randomCensored logical. Show censored values as randomized.
 #' @param \dots arbitrary graphical parameters that will be passed to genericEGRETDotPlot function (see ?par for options)
 #' @keywords graphics water-quality statistics
 #' @export
@@ -35,7 +36,7 @@
 #' plotFluxPred(eList)
 plotFluxPred<-function(eList, fluxUnit = 3, fluxMax = NA, 
                        printTitle = TRUE, oneToOneLine=TRUE, customPar=FALSE,col="black", lwd=1,
-                       cex=0.8, cex.axis=1.1,cex.main=1.1,tinyPlot=FALSE,logScale=FALSE,...){
+                       cex=0.8, cex.axis=1.1,cex.main=1.1,tinyPlot=FALSE,logScale=FALSE,randomCensored = FALSE,...){
   # this function shows observed versus estimated flux
   # estimated flux on the x-axis (these include the bias correction), 
   # observed flux on y-axis 
@@ -108,21 +109,40 @@ plotFluxPred<-function(eList, fluxUnit = 3, fluxMax = NA,
 
   xInfo <- generalAxis(x=x, minVal=minX, maxVal=NA, logScale=logScale, tinyPlot=tinyPlot,padPercent=5)  
 
-  yLow<-localSample$ConcLow*localSample$Q*fluxFactor
-  yHigh<-localSample$ConcHigh*localSample$Q*fluxFactor
-  
-  yInfo <- generalAxis(x=yHigh, minVal=minY, maxVal=fluxMax, logScale=logScale, tinyPlot=tinyPlot,padPercent=5)
-  
-  genericEGRETDotPlot(x=x, y=yHigh,
-                      xTicks=xInfo$ticks, yTicks=yInfo$ticks,
-                      xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
-                      xlab=xLab, ylab=yLab,log=logText, customPar=customPar,
-                      plotTitle=plotTitle,oneToOneLine=oneToOneLine, cex=cex,col=col,
-                      tinyPlot=tinyPlot,cex.axis=cex.axis,cex.main=cex.main,...
-  )
-  
-  censoredSegments(yBottom=yInfo$bottom, yLow=yLow, yHigh=yHigh, x=x, Uncen=Uncen,col=col,lwd=lwd)
-
+  if(!randomCensored){
+    yLow<-localSample$ConcLow*localSample$Q*fluxFactor
+    yHigh<-localSample$ConcHigh*localSample$Q*fluxFactor
+    
+    yInfo <- generalAxis(x=yHigh, minVal=minY, maxVal=fluxMax, logScale=logScale, tinyPlot=tinyPlot,padPercent=5)
+    
+    genericEGRETDotPlot(x=x, y=yHigh,
+                        xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        xlab=xLab, ylab=yLab,log=logText, customPar=customPar,
+                        plotTitle=plotTitle,oneToOneLine=oneToOneLine, cex=cex,col=col,
+                        tinyPlot=tinyPlot,cex.axis=cex.axis,cex.main=cex.main,...
+    )
+    
+    censoredSegments(yBottom=yInfo$bottom, yLow=yLow, yHigh=yHigh, x=x, Uncen=Uncen,col=col,lwd=lwd)
+  } else {
+    if(!("rObserved" %in% names(localSample))){
+      eList <- makeAugmentedSample(eList)
+      localSample <- eList$Sample
+    }
+    yLow<-localSample$rObserved*localSample$Q*fluxFactor
+    yHigh<-localSample$rObserved*localSample$Q*fluxFactor
+    
+    yInfo <- generalAxis(x=yHigh, minVal=minY, maxVal=fluxMax, logScale=logScale, tinyPlot=tinyPlot,padPercent=5)
+    
+    genericEGRETDotPlot(x=x[Uncen == 1], y=yHigh[Uncen == 1],
+                        xTicks=xInfo$ticks, yTicks=yInfo$ticks,
+                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom,yInfo$top),
+                        xlab=xLab, ylab=yLab,log=logText, customPar=customPar,
+                        plotTitle=plotTitle,oneToOneLine=oneToOneLine, cex=cex,col=col,
+                        tinyPlot=tinyPlot,cex.axis=cex.axis,cex.main=cex.main,...
+    )
+    points(x=x[Uncen == 0], y=yHigh[Uncen == 0], pch=1,cex=cex,col=col)
+  }
   if (!tinyPlot) mtext(title2,side=3,line=-1.5)
 
 }
\ No newline at end of file
