@@ -22,6 +22,7 @@
 #' (for example, adjusting margins with par(mar=c(5,5,5,5))). If customPar FALSE, EGRET chooses the best margins depending on tinyPlot.
 #' @param col color of points on plot, see ?par 'Color Specification'
 #' @param lwd number line width
+#' @param randomCensored logical. Show censored residuals as randomized.
 #' @param \dots arbitrary graphical parameters that will be passed to genericEGRETDotPlot function (see ?par for options)
 #' @keywords graphics water-quality statistics
 #' @export
@@ -35,7 +36,7 @@
 #' plotResidTime(eList)
 plotResidTime<-function(eList, stdResid = FALSE, 
                         printTitle = TRUE, hLine=TRUE, tinyPlot=FALSE,col="black",lwd=1,
-                        cex=0.8, cex.axis=1.1,cex.main=1.1, customPar=FALSE,...){
+                        cex=0.8, cex.axis=1.1,cex.main=1.1, customPar=FALSE,randomCensored=FALSE,...){
 
   localINFO <- getInfo(eList)
   localSample <- getSample(eList)
@@ -72,7 +73,7 @@ plotResidTime<-function(eList, stdResid = FALSE,
   
   xInfo <- generalAxis(x=x, maxVal=xMax, minVal=xMin,padPercent=0, tinyPlot=tinyPlot)
   
-  # if(!rResid){
+  if(!randomCensored){
     yLow<-log(localSample$ConcLow)-localSample$yHat
     yHigh<-log(localSample$ConcHigh)-localSample$yHat
     
@@ -91,30 +92,30 @@ plotResidTime<-function(eList, stdResid = FALSE,
     )
     censoredSegments(yInfo$bottom, yLow, yHigh, x, Uncen,col=col,lwd=lwd)
     
-  # } else {
-  #   if(!("rResid" %in% names(localSample))){
-  #     eList <- makeAugmentedSample(eList)
-  #     localSample <- eList$Sample
-  #   }
-  #   yHigh <- localSample$rResid
-  #   
-  #   if(stdResid){
-  #     yHigh <- yHigh/localSample$SE
-  #   }
-  #   
-  #   yInfo <- generalAxis(x=yHigh, maxVal=NA, minVal=NA,padPercent=5, tinyPlot=tinyPlot)
-  #   
-  #   genericEGRETDotPlot(x=x[Uncen == 1], y=yHigh[Uncen == 1],
-  #                       xTicks=xInfo$ticks, yTicks=yInfo$ticks,col=col,
-  #                       xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom, yInfo$top),
-  #                       xlab=xLab, ylab=yLab, plotTitle=plotTitle, customPar=customPar, cex=cex,
-  #                       cex.axis=cex.axis,cex.main=cex.main, hLine=hLine, tinyPlot=tinyPlot,...
-  #   )
-  #   points(x=x[Uncen == 0], y=yHigh[Uncen == 0],cex=cex,col=col)
-  #   
-  # }
+  } else {
+    if(!("rResid" %in% names(localSample))){
+      eList <- makeAugmentedSample(eList)
+      localSample <- eList$Sample
+    }
+    yHigh <- localSample$rResid
+
+    if(stdResid){
+      yHigh <- yHigh/localSample$SE
+    }
+
+    yInfo <- generalAxis(x=yHigh, maxVal=NA, minVal=NA,padPercent=5, tinyPlot=tinyPlot)
+
+    genericEGRETDotPlot(x=x[Uncen == 1], y=yHigh[Uncen == 1],
+                        xTicks=xInfo$ticks, yTicks=yInfo$ticks,col=col,
+                        xlim=c(xInfo$bottom,xInfo$top), ylim=c(yInfo$bottom, yInfo$top),
+                        xlab=xLab, ylab=yLab, plotTitle=plotTitle, customPar=customPar, cex=cex,
+                        cex.axis=cex.axis,cex.main=cex.main, hLine=hLine, tinyPlot=tinyPlot,...
+    )
+    points(x=x[Uncen == 0], y=yHigh[Uncen == 0],cex=cex,col=col)
+
+  }
   
   if (!tinyPlot) mtext(title2,side=3,line=-1.5)
 
-  # invisible(eList)
+  invisible(eList)
 }
\ No newline at end of file
